pub enum WrappedFungibleOperation {
Balance {
owner: AccountOwner,
},
TickerSymbol,
Approve {
owner: AccountOwner,
spender: AccountOwner,
allowance: Amount,
},
Transfer {
owner: AccountOwner,
amount: Amount,
target_account: Account,
},
TransferFrom {
owner: AccountOwner,
spender: AccountOwner,
amount: Amount,
target_account: Account,
},
Claim {
source_account: Account,
amount: Amount,
target_account: Account,
},
Mint {
target_account: Account,
amount: Amount,
},
Burn {
owner: AccountOwner,
amount: Amount,
},
}Expand description
Operations for the wrapped fungible token application.
Variants
Balance
Requests an account balance.
Fields
owner: AccountOwnerOwner to query the balance for
TickerSymbol
Requests this fungible token’s ticker symbol.
Approve
Approve the transfer of tokens
Transfer
Transfers tokens from a (locally owned) account to a (possibly remote) account.
Fields
owner: AccountOwnerOwner to transfer from
TransferFrom
Transfers tokens from a (locally owned) account to a (possibly remote) account by using the allowance.
Claim
Same as Transfer but the source account may be remote. Depending on its
configuration, the target chain may take time or refuse to process
the message.
Fields
Mint
Mints new tokens to a target account. Only the authorized minter can call this.
Fields
Burn
Burns tokens from an account. Rejected by the contract — burning happens automatically when tokens are transferred to an Address20 on the bridge chain.
Fields
owner: AccountOwnerAccount owner whose tokens to burn